package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.constant.CommonAttributes;
import cn.wisenergy.common.utils.DateUtil;
import cn.wisenergy.common.utils.R;
import cn.wisenergy.mapper.*;
import cn.wisenergy.model.app.*;

import cn.wisenergy.model.dto.AccountInfoQuery;
import cn.wisenergy.model.dto.MemberPercentQuery;
import cn.wisenergy.model.enums.*;
import cn.wisenergy.model.vo.TeamPerformanceSortVo;
import cn.wisenergy.service.Manager.PublicManager;
import cn.wisenergy.service.app.AccountService;
import cn.wisenergy.service.Manager.AccountManager;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageInfo;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.*;


/**
 * @author 86187
 */
@Slf4j
@Service
public class AccountServiceImpl extends ServiceImpl<AccountMapper, AccountInfo> implements AccountService {


    @Autowired
    private AccountMapper accountMapper;

    @Autowired
    private TradeRecordMapper tradeRecordMapper;

    /**
     * 测试安卓包路径：https://www.xitiansen.com/upload/app-debug.apk
     * 线上安卓包路径：http://app.xitiansen.com/upload/xitiansen.apk
     */
    private static final String DOWNLOAD_URL = "https://www.xitiansen.com/upload/app-debug.apk";

    @Override
    public R<AccountInfo> getByUserId(String userId) {
        AccountInfo accountInfo = accountMapper.getByUserId(userId);
        return R.ok(accountInfo);
    }

    @Override
    public R<PageInfo<AccountInfo>> getList(AccountInfoQuery query) {
        log.info("shop-mall[]AccountServiceImpl[]getList[]input.param.query:" + query);
        if (null == query) {
            return R.error("入参不能为空!");
        }

        pageHandle(query);

        Map<String, Object> map = new HashMap<>();
        int total = accountMapper.count();

        map.put("startNum", query.getStartNum());
        map.put("endNum", query.getEndNum());
        List<AccountInfo> list = accountMapper.getList(map);
        PageInfo<AccountInfo> info = new PageInfo<>();
        info.setPageSize(query.getPageSize());
        info.setPageNum(query.getPageNo());
        info.setTotal(total);
        info.setList(list);
        return R.ok(info);
    }

    @Override
    public R<String> updateVersion(String version) {
        log.info("shop-mall[]AccountServiceImpl[]updateVersion[]input.param.version:" + version);
        if (StringUtils.isBlank(version)) {
            return R.error("入参不能为空!");
        }

        //获取版本号信息
        TradeRecord tradeRecord = tradeRecordMapper.getVersion();
        if (null == tradeRecord) {
            return R.error("版本号信息不存在,请联系管理员!");
        }

        //版本号不相等
        if (!tradeRecord.getTradeNo().equals(version)) {
            return R.ok(DOWNLOAD_URL);
        }
        return R.error(1, "当前已是最新版本!");
    }

    /**
     * 分页处理方法
     *
     * @param schemeVo 参数
     */
    private void pageHandle(AccountInfoQuery schemeVo) {
        Integer pageNum = schemeVo.getPageNo();
        Integer pageSize = schemeVo.getPageSize();
        if (null == pageSize || pageSize == 0) {
            pageSize = 10;
        }
        if (null == pageNum || pageNum == 0) {
            pageNum = 1;
        }
        Integer endNum = pageSize;
        Integer startNum = (pageNum - CommonAttributes.NUM_ONE) * pageSize;
        schemeVo.setEndNum(endNum);
        schemeVo.setStartNum(startNum);
        schemeVo.setPageNo(pageNum);
        schemeVo.setPageSize(pageSize);
    }
}
